==> sms-service-1.8.0-sources.jar: org/opennms/sms/reflector/smsservice/MobileMsgTracker.java <==
/*
 * This file is part of the OpenNMS(R) Application.
 *
 * OpenNMS(R) is Copyright (C) 2009 The OpenNMS Group, Inc.  All rights reserved.
 * OpenNMS(R) is a derivative work, containing both original code, included code and modified
 * code that was published under the GNU General Public License. Copyrights for modified
 * and included code are below.
 *
 * OpenNMS(R) is a registered trademark of The OpenNMS Group, Inc.
 *
 * Original code base Copyright (C) 1999-2001 Oculan Corp.  All rights reserved.
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
 *
 * For more information contact:
 * OpenNMS Licensing       <license@opennms.org>
 *     http://www.opennms.org/
 *     http://www.opennms.com/
 */
package org.opennms.sms.reflector.smsservice;

import org.smslib.OutboundMessage;
import org.smslib.USSDRequest;

/**
 * MobileMsgTracker
 *
 * @author brozow
 */
public interface MobileMsgTracker {

    public abstract MobileMsgRequest sendSmsRequest(OutboundMessage msg, long timeout,
            int retries, MobileMsgResponseCallback cb,
            MobileMsgResponseMatcher matcher) throws Exception;

    public abstract MobileMsgRequest sendUssdRequest(USSDRequest msg,
            long timeout, int retries, MobileMsgResponseCallback cb,
            MobileMsgResponseMatcher matcher) throws Exception;

}

==> sms-service-1.8.6-sources.jar: org/opennms/sms/reflector/smsservice/MobileMsgTracker.java <==
/*
 * This file is part of the OpenNMS(R) Application.
 *
 * OpenNMS(R) is Copyright (C) 2009 The OpenNMS Group, Inc.  All rights reserved.
 * OpenNMS(R) is a derivative work, containing both original code, included code and modified
 * code that was published under the GNU General Public License. Copyrights for modified
 * and included code are below.
 *
 * OpenNMS(R) is a registered trademark of The OpenNMS Group, Inc.
 *
 * Original code base Copyright (C) 1999-2001 Oculan Corp.  All rights reserved.
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
 *
 * For more information contact:
 * OpenNMS Licensing       <license@opennms.org>
 *     http://www.opennms.org/
 *     http://www.opennms.com/
 */
package org.opennms.sms.reflector.smsservice;

import org.smslib.OutboundMessage;
import org.smslib.USSDRequest;

/**
 * MobileMsgTracker
 *
 * @author brozow
 * @version $Id: $
 */
public interface MobileMsgTracker {

    /**
     * <p>sendSmsRequest</p>
     *
     * @param msg a {@link org.smslib.OutboundMessage} object.
     * @param timeout a long.
     * @param retries a int.
     * @param cb a {@link org.opennms.sms.reflector.smsservice.MobileMsgResponseCallback} object.
     * @param matcher a {@link org.opennms.sms.reflector.smsservice.MobileMsgResponseMatcher} object.
     * @return a {@link org.opennms.sms.reflector.smsservice.MobileMsgRequest} object.
     * @throws java.lang.Exception if any.
     */
    public abstract MobileMsgRequest sendSmsRequest(OutboundMessage msg, long timeout,
            int retries, MobileMsgResponseCallback cb,
            MobileMsgResponseMatcher matcher) throws Exception;

    /**
     * <p>sendUssdRequest</p>
     *
     * @param msg a {@link org.smslib.USSDRequest} object.
     * @param timeout a long.
     * @param retries a int.
     * @param cb a {@link org.opennms.sms.reflector.smsservice.MobileMsgResponseCallback} object.
     * @param matcher a {@link org.opennms.sms.reflector.smsservice.MobileMsgResponseMatcher} object.
     * @return a {@link org.opennms.sms.reflector.smsservice.MobileMsgRequest} object.
     * @throws java.lang.Exception if any.
     */
    public abstract MobileMsgRequest sendUssdRequest(USSDRequest msg,
            long timeout, int retries, MobileMsgResponseCallback cb,
            MobileMsgResponseMatcher matcher) throws Exception;

}
